package com.huiju.estateagents.redpack.controller;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.RestController;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.huiju.estateagents.base.BaseController;
import com.huiju.estateagents.base.ResponseBean;
import com.huiju.estateagents.redpack.entity.TaOrgAccountDetailedList;
import com.huiju.estateagents.redpack.service.ITaOrgAccountDetailedListService;

/**
 * <p>
    * 账户消费流水  前端控制器
    * </p>
 *
 * @author fxf
 * @since 2020-06-03
 */
@RestController
@RequestMapping("/")
public class TaOrgAccountDetailedListController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaOrgAccountDetailedListController.class);

    @Autowired
    public ITaOrgAccountDetailedListService iTaOrgAccountDetailedListService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/taOrgAccountDetailedList",method= RequestMethod.GET)
    public ResponseBean taOrgAccountDetailedListList(@RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                                     @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize){
        ResponseBean responseBean = new ResponseBean();
        try {
            //使用分页插件
		    IPage<TaOrgAccountDetailedList> pg = new Page<>(pageNum, pageSize);
            QueryWrapper<TaOrgAccountDetailedList> queryWrapper = new QueryWrapper<>();
            queryWrapper.orderByDesc("create_date");

            IPage<TaOrgAccountDetailedList> result = iTaOrgAccountDetailedListService.page(pg, queryWrapper);
            responseBean.addSuccess(result);
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taOrgAccountDetailedListList -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 保存对象
     * @param taOrgAccountDetailedList 实体对象
     * @return
     */
    @RequestMapping(value="/taOrgAccountDetailedList",method= RequestMethod.POST)
    public ResponseBean taOrgAccountDetailedListAdd(@RequestBody TaOrgAccountDetailedList taOrgAccountDetailedList){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iTaOrgAccountDetailedListService.save(taOrgAccountDetailedList)){
                responseBean.addSuccess(taOrgAccountDetailedList);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taOrgAccountDetailedListAdd -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @ResponseBody
    @RequestMapping(value="/taOrgAccountDetailedList/{id}", method= RequestMethod.DELETE)
    public ResponseBean taOrgAccountDetailedListDelete(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            if(iTaOrgAccountDetailedListService.removeById(id)){
                responseBean.addSuccess("success");
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taOrgAccountDetailedListDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param taOrgAccountDetailedList 实体对象
     * @return
     */
    @RequestMapping(value="/taOrgAccountDetailedList/{id}",method= RequestMethod.PUT)
    public ResponseBean taOrgAccountDetailedListUpdate(@PathVariable Integer id,
                                        @RequestBody TaOrgAccountDetailedList taOrgAccountDetailedList){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iTaOrgAccountDetailedListService.updateById(taOrgAccountDetailedList)){
                responseBean.addSuccess(taOrgAccountDetailedList);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taOrgAccountDetailedListUpdate -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/taOrgAccountDetailedList/{id}",method= RequestMethod.GET)
    public ResponseBean taOrgAccountDetailedListGet(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            responseBean.addSuccess(iTaOrgAccountDetailedListService.getById(id));
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taOrgAccountDetailedListDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }
}
